aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/Updates/InstallationInfo.cs
diff options
context:
space:
mode:
authorNyanmisaka <nst799610810@gmail.com>2020-06-25 16:37:40 +0800
committerGitHub <noreply@github.com>2020-06-25 16:37:40 +0800
commit912946a42793305ecdc6a8c176f1775ffe7ac0de (patch)
tree6a4d85c4869ed8cb5d15f3fa8c82512de6405b6e /MediaBrowser.Model/Updates/InstallationInfo.cs
parentbfd87829e3bca42a245287b99e652d091b21c990 (diff)
parent91c51ae6752720d6272e6a0c651edd3780e150ac (diff)
Merge pull request from jellyfin/master
Diffstat (limited to 'MediaBrowser.Model/Updates/InstallationInfo.cs')
-rw-r--r--MediaBrowser.Model/Updates/InstallationInfo.cs31
1 files changed, 19 insertions, 12 deletions
diff --git a/MediaBrowser.Model/Updates/InstallationInfo.cs b/MediaBrowser.Model/Updates/InstallationInfo.cs
index 42c2105f54..a6d80dba62 100644
--- a/MediaBrowser.Model/Updates/InstallationInfo.cs
+++ b/MediaBrowser.Model/Updates/InstallationInfo.cs
@@ -1,3 +1,4 @@
+#nullable disable
using System;
namespace MediaBrowser.Model.Updates
@@ -8,10 +9,10 @@ namespace MediaBrowser.Model.Updates
public class InstallationInfo
{
/// <summary>
- /// Gets or sets the id.
+ /// Gets or sets the guid.
/// </summary>
- /// <value>The id.</value>
- public Guid Id { get; set; }
+ /// <value>The guid.</value>
+ public Guid Guid { get; set; }
/// <summary>
/// Gets or sets the name.
@@ -20,21 +21,27 @@ namespace MediaBrowser.Model.Updates
public string Name { get; set; }
/// <summary>
- /// Gets or sets the assembly guid.
+ /// Gets or sets the version.
/// </summary>
- /// <value>The guid of the assembly.</value>
- public string AssemblyGuid { get; set; }
+ /// <value>The version.</value>
+ public Version Version { get; set; }
/// <summary>
/// Gets or sets the version.
/// </summary>
- /// <value>The version.</value>
- public string Version { get; set; }
+ /// <value>The changelog.</value>
+ public string Changelog { get; set; }
+
+ /// <summary>
+ /// Gets or sets the source URL.
+ /// </summary>
+ /// <value>The source URL.</value>
+ public string SourceUrl { get; set; }
/// <summary>
/// Gets or sets the update class.
/// </summary>
- /// <value>The update class.</value>
- public PackageVersionClass UpdateClass { get; set; }
+ /// <value>The checksum.</value>
+ public string Checksum { get; set; }
}
}
@@ -20,21 +21,27 @@ namespace MediaBrowser.Model.Updates
/// <summary>
- /// Gets or sets the version.
+ /// Gets or sets the changelog for this version.
/// </summary>
@@ -20,21 +21,27 @@ namespace MediaBrowser.Model.Updates
/// <summary>
- /// Gets or sets the update class.
+ /// Gets or sets a checksum for the binary.
/// </summary>